==> openshift-model-config-6.1.1-sources.jar: io/fabric8/openshift/api/model/config/v1/AuditFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AuditFluent<A extends AuditFluent<A>> extends Fluent<A>{
  public A addToCustomRules(Integer index,AuditCustomRule item);
  public A setToCustomRules(Integer index,AuditCustomRule item);
  public A addToCustomRules(io.fabric8.openshift.api.model.config.v1.AuditCustomRule... items);
  public A addAllToCustomRules(Collection<AuditCustomRule> items);
  public A removeFromCustomRules(io.fabric8.openshift.api.model.config.v1.AuditCustomRule... items);
  public A removeAllFromCustomRules(Collection<AuditCustomRule> items);
  public A removeMatchingFromCustomRules(Predicate<AuditCustomRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCustomRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AuditCustomRule> getCustomRules();
  public List<AuditCustomRule> buildCustomRules();
  public AuditCustomRule buildCustomRule(Integer index);
  public AuditCustomRule buildFirstCustomRule();
  public AuditCustomRule buildLastCustomRule();
  public AuditCustomRule buildMatchingCustomRule(Predicate<AuditCustomRuleBuilder> predicate);
  public Boolean hasMatchingCustomRule(Predicate<AuditCustomRuleBuilder> predicate);
  public A withCustomRules(List<AuditCustomRule> customRules);
  public A withCustomRules(io.fabric8.openshift.api.model.config.v1.AuditCustomRule... customRules);
  public Boolean hasCustomRules();
  public A addNewCustomRule(String group,String profile);
  public AuditFluent.CustomRulesNested<A> addNewCustomRule();
  public AuditFluent.CustomRulesNested<A> addNewCustomRuleLike(AuditCustomRule item);
  public AuditFluent.CustomRulesNested<A> setNewCustomRuleLike(Integer index,AuditCustomRule item);
  public AuditFluent.CustomRulesNested<A> editCustomRule(Integer index);
  public AuditFluent.CustomRulesNested<A> editFirstCustomRule();
  public AuditFluent.CustomRulesNested<A> editLastCustomRule();
  public AuditFluent.CustomRulesNested<A> editMatchingCustomRule(Predicate<AuditCustomRuleBuilder> predicate);
  public String getProfile();
  public A withProfile(String profile);
  public Boolean hasProfile();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CustomRulesNested<N> extends Nested<N>,AuditCustomRuleFluent<AuditFluent.CustomRulesNested<N>>{
    public N and();
    public N endCustomRule();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/AuditFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AuditFluent<A extends AuditFluent<A>> extends Fluent<A>{
  public A addToCustomRules(int index,AuditCustomRule item);
  public A setToCustomRules(int index,AuditCustomRule item);
  public A addToCustomRules(io.fabric8.openshift.api.model.config.v1.AuditCustomRule... items);
  public A addAllToCustomRules(Collection<AuditCustomRule> items);
  public A removeFromCustomRules(io.fabric8.openshift.api.model.config.v1.AuditCustomRule... items);
  public A removeAllFromCustomRules(Collection<AuditCustomRule> items);
  public A removeMatchingFromCustomRules(Predicate<AuditCustomRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCustomRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AuditCustomRule> getCustomRules();
  public List<AuditCustomRule> buildCustomRules();
  public AuditCustomRule buildCustomRule(int index);
  public AuditCustomRule buildFirstCustomRule();
  public AuditCustomRule buildLastCustomRule();
  public AuditCustomRule buildMatchingCustomRule(Predicate<AuditCustomRuleBuilder> predicate);
  public Boolean hasMatchingCustomRule(Predicate<AuditCustomRuleBuilder> predicate);
  public A withCustomRules(List<AuditCustomRule> customRules);
  public A withCustomRules(io.fabric8.openshift.api.model.config.v1.AuditCustomRule... customRules);
  public Boolean hasCustomRules();
  public A addNewCustomRule(String group,String profile);
  public AuditFluent.CustomRulesNested<A> addNewCustomRule();
  public AuditFluent.CustomRulesNested<A> addNewCustomRuleLike(AuditCustomRule item);
  public AuditFluent.CustomRulesNested<A> setNewCustomRuleLike(int index,AuditCustomRule item);
  public AuditFluent.CustomRulesNested<A> editCustomRule(int index);
  public AuditFluent.CustomRulesNested<A> editFirstCustomRule();
  public AuditFluent.CustomRulesNested<A> editLastCustomRule();
  public AuditFluent.CustomRulesNested<A> editMatchingCustomRule(Predicate<AuditCustomRuleBuilder> predicate);
  public String getProfile();
  public A withProfile(String profile);
  public Boolean hasProfile();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CustomRulesNested<N> extends Nested<N>,AuditCustomRuleFluent<AuditFluent.CustomRulesNested<N>>{
    public N and();
    public N endCustomRule();
    
  }
  
}
